Forgot Password
===============
App for a user who forgot their password.

Flow
====
1. Navigate to forgot password page
2. Enter the email address in the field provided
3. Assuming the the email address is valid, send an email to the user who's email was provided letting them know their username.